==> testbot-1.1.1.tar.gz: lib/src/controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:testbot/src/apiservice.dart';
import 'package:testbot/src/common_name.dart';
import 'package:testbot/src/model/issue_type_models.dart';
import 'package:testbot/src/model/support_details_model.dart';

class Controller extends GetxController {
  RxList fileList = [].obs;
  RxString issueType = "Select".obs;
  TextEditingController description = TextEditingController();
  RxList<String> issueTypeList = [CommonName.select].obs;
  var supportDetailsModel = SupportDetailsModel().obs;

  getsupportdata(String empid, String clientid) async {
    var data = await APICalls.apicall(
        requests: "POST",
        param: {"EmployeeId": "36370", "Client": "3008"},
        uri: "http://devsupport.ppms.co.in/api/ChatBot/GetEmployeeDetailsById",
        label: "GetSupportInfoApi");
    supportDetailsModel.value = SupportDetailsModel();
    if (data[0]) {
      supportDetailsModel.value = supportDetailsModelFromJson(data[1]);
    }
    // print("supportList => ${data[1]}");
    // print("supportListsize => ${data.length}");
  }

  getissuetypedata() async {
    var dropdowndata = await APICalls.apicall(
        requests: "GET",
        label: "GetIssueTypes",
        uri: "http://devsupport.ppms.co.in/api/ChatBot/GetIssueTyeMaster");
    List<IssueTypeModel> c = [];
    if (dropdowndata[0]) {
      c = issueTypeModelFromJson(dropdowndata[1]);
    }
    issueTypeList.value = [CommonName.select];
    for (int i = 0; i < c.length; i++) {
      issueTypeList.add(c[i].issueTypeName!);
      print("${issueTypeList.toString()}");
    }
  }
}

==> testbot-1.1.3.tar.gz: lib/src/controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:testbot/src/apiservice.dart';
import 'package:testbot/src/common_name.dart';
import 'package:testbot/src/model/issue_type_models.dart';
import 'package:testbot/src/model/support_details_model.dart';

class Controller extends GetxController {
  RxList fileList = [].obs;
  RxString issueType = "Select".obs;
  TextEditingController description = TextEditingController();
  RxList<String> issueTypeList = [CommonName.select].obs;
  var supportDetailsModel = SupportDetailsModel().obs;

  getsupportdata(String empid, String clientid) async {
    var data = await APICalls.apicall(
        requests: "POST",
        param: {"EmployeeId": empid, "Client": clientid},
        uri: "http://devsupport.ppms.co.in/api/ChatBot/GetEmployeeDetailsById",
        label: "GetSupportInfoApi");
    supportDetailsModel.value = SupportDetailsModel();
    if (data[0]) {
      supportDetailsModel.value = supportDetailsModelFromJson(data[1]);
    }
    // print("supportList => ${data[1]}");
    // print("supportListsize => ${data.length}");
  }

  getissuetypedata() async {
    var dropdowndata = await APICalls.apicall(
        requests: "GET",
        label: "GetIssueTypes",
        uri: "http://devsupport.ppms.co.in/api/ChatBot/GetIssueTyeMaster");
    List<IssueTypeModel> c = [];
    if (dropdowndata[0]) {
      c = issueTypeModelFromJson(dropdowndata[1]);
    }
    issueTypeList.value = [CommonName.select];
    for (int i = 0; i < c.length; i++) {
      issueTypeList.add(c[i].issueTypeName!);
      print("${issueTypeList.toString()}");
    }
  }
}
